#
# spec file for package ocsync
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ocsync
BuildRequires:  check
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libsmbclient-devel
%if 0%{?suse_version}
BuildRequires:  libiniparser-devel
BuildRequires:  libneon-devel
BuildRequires:  libssh-devel
BuildRequires:  sqlite3-devel
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  libiniparser-devel
BuildRequires:  libssh2-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%endif
%if 0%{?fedora_version}
BuildRequires:  iniparser-devel
BuildRequires:  libssh-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%if 0%{?fedora_version} > 16
BuildRequires:  samba4-libs
%endif
%endif
%if 0%{?mdk_version}
BuildRequires:  iniparser-devel
BuildRequires:  libssh-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%endif

Version:        0.70.7
Release:        26.1
Summary:        A user level bidirectional client only file synchronizer (owncloud version)
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            http://www.csync.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        baselibs.conf
%if 0%{?sles_version} || 0%{?centos_version} || 0%{?rhel_version}
Patch0:         remove_signal-0.70.4.dif
%endif
%if 0%{?fedora_version} > 16
Patch1:         iniparser_fed17.dif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ocsync is the ownCloud version of csync. csync is an implementation of 
a file synchronizer which provides the feature of roaming home directories 
for Linux clients.

%package -n libocsync0
Summary:        A user level bidirectional client only file synchronizer
Group:          System/Libraries
%if 0%{?suse_version} > 1030
Recommends:     libocsync-plugin-owncloud
%endif

%description -n libocsync0
ocsync is a csync version which is temporarily maintained by the ownCloud
community to support the ownCloud client. csync is an implementation of a 
file synchronizer which provides the feature of roaming home directories 
for Linux clients. csync makes use of libsmbclient in Samba/Windows 
environments.

%package -n libocsync-plugin-smb
Summary:        SMB plugin for ocsync
Group:          System/Libraries
Requires:       libocsync0 = %{version}

%description -n libocsync-plugin-smb
This plug-in allows applications using ocsync to synchronize with a
Samba or Windows server.

%if 0%{?fedora_version} || 0%{?suse_version} || 0%{?mdk_version}
%if !0%{?sles_version}

%package -n libocsync-plugin-sftp
Summary:        A user level bidirectional client only file synchronizer
Group:          Productivity/Networking/Other
Requires:       libocsync0 = %{version}

%description -n libocsync-plugin-sftp
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for clients. csync makes use
of libsmbclient in Samba/Windows environments.
%endif
%else
# disabled due to old libssh on centos, rhel and sles
%endif

%package -n libocsync-plugin-owncloud
Summary:        A user level bidirectional client only file synchronizer
Group:          Productivity/Networking/Other
Requires:       libocsync0 = %{version}

%description -n libocsync-plugin-owncloud
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libneon to access ownCloud. 

%package -n libocsync-devel
Summary:        Development files for csync
Group:          Development/Libraries/C and C++
Requires:       libocsync0 = %{version}

%description -n libocsync-devel
The libocsync-devel package contains the static libraries and header
files needed for development with csync.

%package -n libocsync-devel-doc
Summary:        Developer documentation for csync
Group:          Development/Languages/C and C++

%description -n libocsync-devel-doc
The libocsync-devel-doc package provides documentation for csync
development.

%package -n libocsync-doc
Summary:        User documentation for csync
Group:          Development/Languages/C and C++

%description -n libocsync-doc
The libocsync-doc package provides user documentation for csync.

%prep
%setup -q
%if 0%{?sles_version} || 0%{?rhel_version} || 0%{?centos_version}
%patch0 -p 1 
%endif
%if 0%{?fedora_version} > 16
%patch1 -p 1
%endif

%build
if test ! -e "build"; then
  %{__mkdir} build
fi
pushd build
cmake \
  -DCMAKE_C_FLAGS:STRING="%{optflags}" \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DSYSCONF_INSTALL_DIR=%{_sysconfdir} \
%if %{_lib} == lib64
  -DLIB_SUFFIX=64 \
%endif
  %{_builddir}/%{name}-%{version}
%__make %{?jobs:-j%jobs} VERBOSE=1
%__make doc
popd build

%install
pushd build
%if 0%{?suse_version}
%makeinstall
%else
make DESTDIR=%{buildroot} install
%endif
popd build

%post -n libocsync0
/sbin/ldconfig

%postun -n libocsync0
/sbin/ldconfig

%clean
%__rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/ocsync
%{_mandir}/man?/ocsync.*

%files -n libocsync0
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL README
%dir %{_sysconfdir}/ocsync
%config(noreplace) %{_sysconfdir}/ocsync/ocsync.conf
%config(noreplace) %{_sysconfdir}/ocsync/ocsync_exclude.conf
%{_libdir}/libocsync.so.*
%dir %{_libdir}/ocsync-0

%files -n libocsync-plugin-smb
%defattr(-,root,root)
%{_libdir}/ocsync-0/ocsync_smb.so

%if 0%{?suse_version} || 0%{?fedora_version} || 0%{?mdk_version}
%if !0%{?sles_version}

%files -n libocsync-plugin-sftp
%defattr(-,root,root)
%{_libdir}/ocsync-0/ocsync_sftp.so
%endif
%else
#disabled on rhel, sles and centos due to old libssh version
%endif

%files -n libocsync-plugin-owncloud
%defattr(-,root,root)
%{_libdir}/ocsync-0/ocsync_owncloud.so

%files -n libocsync-devel
%defattr(-,root,root)
%{_includedir}/ocsync
%{_libdir}/libocsync.so

%files -n libocsync-devel-doc
%defattr(-,root,root)
%doc build/doc/html

%files -n libocsync-doc
%defattr(-,root,root)
%{_datadir}/doc/ocsync

%changelog
* Sat May  4 2013 cs@linux-administrator.com
- update to 0.70.7
